@@ -9,6 +9,7 @@ from edc_auth.utils import remove_default_model_permissions_from_edc_permissions
 
 from .auth_objects import (
     ACTION_ITEM,
+    ACTION_ITEM_EXPORT,
     ACTION_ITEM_VIEW_ONLY,
     action_items_codenames,
     navbar_tuples,
@@ -25,6 +26,12 @@ site_auths.add_custom_permissions_tuples(
 
 site_auths.add_group(*action_items_codenames, name=ACTION_ITEM)
 site_auths.add_group(*action_items_codenames, name=ACTION_ITEM_VIEW_ONLY, view_only=True)
+site_auths.add_group(
+    "edc_action_item.export_actionitem",
+    "edc_action_item.export_actiontype",
+    "edc_action_item.export_historicalactionitem",
+    name=ACTION_ITEM_EXPORT,
+)
 
 site_auths.add_custom_permissions_tuples(
     model="edc_action_item.historicalactionitem",
